aboutsummaryrefslogtreecommitdiffstats
path: root/src/pcm_volume.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/pcm_volume.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/pcm_volume.h b/src/pcm_volume.h
index b389dee3c..3fd722e77 100644
--- a/src/pcm_volume.h
+++ b/src/pcm_volume.h
@@ -21,6 +21,7 @@
#define PCM_VOLUME_H
#include "pcm_prng.h"
+#include "audio_format.h"
#include <stdint.h>
#include <stdbool.h>
@@ -62,13 +63,13 @@ pcm_volume_dither(void)
*
* @param buffer the PCM buffer
* @param length the length of the PCM buffer
* @param format the audio format of the PCM buffer
* @param volume the volume between 0 and #PCM_VOLUME_1
* @return true on success, false if the audio format is not supported
*/
bool
pcm_volume(void *buffer, int length,
- const struct audio_format *format,
+ enum sample_format format,
int volume);
#endif
@@ -62,13 +63,13 @@ pcm_volume_dither(void)
* @param buffer the PCM buffer
* @param length the length of the PCM buffer
- * @param format the audio format of the PCM buffer
+ * @param format the sample format of the PCM buffer
* @param volume the volume between 0 and #PCM_VOLUME_1
* @return true on success, false if the audio format is not supported